@@ -9,11 +9,7 @@ from hpccm.building_blocks import (
     packages,
     pip,
 )
-from hpccm.primitives import (
-    baseimage,
-    comment,
-    raw,
-)
+from hpccm.primitives import baseimage, comment, raw, shell
 
 from ogscm.version import __version__
 from ogscm.app import builder
@@ -38,12 +34,6 @@ def main():  # pragma: no cover
     parser.add_argument(
         "--file", type=str, default="", help="Overwrite output recipe file name"
     )
-    parser.add_argument(
-        "--sif_file",
-        type=str,
-        default="",
-        help="Overwrite output singularity image file name",
-    )
     parser.add_argument(
         "--print",
         "-P",
@@ -61,6 +51,12 @@ def main():  # pragma: no cover
         default="ubuntu:20.04",
         help="The base image. (centos:8 is supported too)",
     )
+    general_g.add_argument(
+        "--runtime_base_image",
+        type=str,
+        default="",
+        help="The runtime base image.",
+    )
     build_g = parser.add_argument_group("Image build options")
     build_g.add_argument(
         "--build",
@@ -103,6 +99,37 @@ def main():  # pragma: no cover
         action="store_true",
         help="Convert Docker image to Singularity image",
     )
+    build_g.add_argument(
+        "--sif_file",
+        type=str,
+        default="",
+        help="Overwrite output singularity image file name",
+    )
+    build_g.add_argument(
+        "--convert-enroot",
+        "-E",
+        dest="convert_enroot",
+        action="store_true",
+        help="Convert Docker image to enroot image",
+    )
+    build_g.add_argument(
+        "--enroot-bundle",
+        dest="enroot_bundle",
+        action="store_true",
+        help="Convert enroot image to enroot bundle",
+    )
+    build_g.add_argument(
+        "--enroot_file",
+        type=str,
+        default="",
+        help="Overwrite output enroot image file name",
+    )
+    build_g.add_argument(
+        "--force",
+        dest="force",
+        action="store_true",
+        help="Forces overwriting of image files!",
+    )
     build_g.add_argument(
         "--runtime-only",
         "-R",
@@ -166,7 +193,12 @@ def main():  # pragma: no cover
 
     # Prepare runtime stage
     Stage1 = hpccm.Stage()
-    Stage1.baseimage(image=args.base_image)
+    if args.runtime_base_image == "":
+        Stage1.baseimage(image=args.base_image)
+    else:
+        Stage1.baseimage(image=args.runtime_base_image)
+        if args.runtime_base_image == "jupyter/base-notebook":
+            Stage1 += raw(docker="USER root")
 
     cwd = os.getcwd()
     img_file = ""
@@ -250,9 +282,14 @@ def main():  # pragma: no cover
     stages_string = str(Stage0)
 
     if args.runtime_only:
-        Stage1 += Stage0.runtime(exclude=["boost"])
+        runtime_exclude = []
+        if hasattr(args, "mfront") and not args.mfront:
+            runtime_exclude.append("boost")
+        Stage1 += Stage0.runtime(exclude=runtime_exclude)
         if args.compiler == "gcc" and args.compiler_version != None:
             Stage1 += packages(apt=["libstdc++6"])
+        if args.runtime_base_image == "jupyter/base-notebook":
+            Stage1 += raw(docker="USER ${NB_USER}")
         stages_string += "\n\n" + str(Stage1)
 
     # ---------------------------- recipe end -----------------------------
