@@ -35,7 +35,7 @@ parse_g.add_argument(
     "--mpi_benchmarks",
     dest="mpi_benchmarks",
     action="store_true",
-    help="Installs OSU MPI " "benchmarks as scif app and mpi_bw, mpi_ring," "mpi_hello",
+    help="Installs OSU MPI benchmarks and mpi_bw, mpi_ring, mpi_hello",
 )
 # parse_g.add_argument(
 #     "--ucx",
@@ -121,7 +121,7 @@ Stage0 += shell(
 )
 
 # PMI support
-Stage0 += slurm_pmi2(prefix="/usr/local/pmi")
+Stage0 += slurm_pmi2(prefix="/usr/local/pmi", version="20.11.7")
 Stage0 += pmix()
 
 # OpenMPI
@@ -207,19 +207,5 @@ if local_args.mpi_benchmarks:
             )
         }
     )
-    # Stage0 += osu_benchmarks(toolchain=toolchain)
-    # Stage0 += shell(
-    #     commands=[
-    #         "mkdir -p /usr/local/mpi-examples",
-    #         "cd /usr/local/mpi-examples",
-    #         "curl -O https://raw.githubusercontent.com/hpc/charliecloud/674b3b4e4ad243be5565f200d8f5fb92b7544480/examples/mpihello/hello.c",
-    #         "curl -O https://computing.llnl.gov/tutorials/mpi/samples/C/mpi_bandwidth.c",
-    #         "curl -O https://raw.githubusercontent.com/mpitutorial/mpitutorial/gh-pages/tutorials/mpi-send-and-receive/code/ring.c",
-    #         "mpicc -o /usr/local/bin/mpi-hello /usr/local/mpi-examples/hello.c",
-    #         "mpicc -o /usr/local/bin/mpi-ring /usr/local/mpi-examples/ring.c",
-    #         "mpicc -o /usr/local/bin/mpi-bandwidth /usr/local/mpi-examples/mpi_bandwidth.c",
-    #     ]
-    # )
-    # Stage1 += copy(_from="build", src="/usr/local/bin/mpi-*", dest="/usr/local/bin/")
 
 Stage0 += comment(f"--- End {filename} ---")
