@@ -16,7 +16,6 @@ from hpccm.building_blocks import (
     mkl,
     packages,
     pip,
-    scif,
 )
 from ogscm.building_blocks.pm_conan import pm_conan
 
@@ -141,7 +140,9 @@ if local_args.ogs not in ["off", "clean"]:  # != "off" and local_args.ogs != "cl
         with open(f"{local_args.ogs}/web/data/versions.json") as fp:
             versions = json.load(fp)
         if "GITLAB_CI" in os.environ:
-            if "CI_COMMIT_BRANCH" in os.environ:
+            if "CI_COMMIT_TAG" in os.environ:
+                branch = "master"
+            elif "CI_COMMIT_BRANCH" in os.environ:
                 branch = os.environ["CI_COMMIT_BRANCH"]
             elif "CI_MERGE_REQUEST_SOURCE_BRANCH_NAME" in os.environ:
                 branch = os.environ["CI_MERGE_REQUEST_SOURCE_BRANCH_NAME"]
@@ -163,7 +164,7 @@ if local_args.ogs not in ["off", "clean"]:  # != "off" and local_args.ogs != "cl
                 capture_output=True,
                 text=True,
                 shell=True,
-            ).stdout[0]
+            ).stdout.strip()
     else:
         # Get git commit hash and construct image tag name
         repo, branch, *commit = local_args.ogs.split("@")
@@ -227,11 +228,6 @@ if local_args.ogs != "off" and not args.runtime_only:
 # Optionally set out_dir
 out_dir += folder
 
-if repo == "local":
-    scif_file = f"{out_dir}/ogs.scif"  # TODO
-else:
-    scif_file = f"{out_dir}/ogs.scif"
-
 # Implement recipe
 Stage0 += comment(f"--- Begin {filename} ---")
 
@@ -264,8 +260,8 @@ if local_args.gui:
         yum=["mesa-libOSMesa", "mesa-libGL", "mesa-libGLU", "libXt"],
     )
 if local_args.ogs != "clean":
+    Stage0 += cmake(eula=True, version="3.21.0")
     if local_args.pm == "conan":
-        Stage0 += cmake(eula=True, version="3.19.4")
         conan_user_home = "/opt/conan"
         if local_args.dev:
             conan_user_home = ""
@@ -274,14 +270,22 @@ if local_args.ogs != "clean":
         )
         Stage0 += environment(variables={"CONAN_SYSREQUIRES_SUDO": 0})
     elif local_args.pm == "system":
-        Stage0 += cmake(eula=True, version="3.19.4")
+        boost_bootsrap_opts = []
+        if local_args.mfront:
+            # for mfront python bindings
+            boost_bootsrap_opts = ['--with-python=python3']
+        if toolchain.CC == "clang":
+            boost_bootsrap_opts.append("--with-toolset=clang")
         Stage0 += boost(
+            baseurl=f"https://boostorg.jfrog.io/artifactory/main/release/{versions['minimum_version']['boost']}/source",
             version=versions["minimum_version"]["boost"],
-            bootstrap_opts=["--with-toolset=clang"] if toolchain.CC == "clang" else [],
+            bootstrap_opts=boost_bootsrap_opts,
             b2_opts=["headers"],
         )
         Stage0 += environment(variables={"BOOST_ROOT": "/usr/local/boost"})
-        Stage0 += packages(apt=["libxml2-dev"], yum=["libxml2-devel"])
+        Stage0 += packages(
+            apt=["libxml2-dev", "xsltproc"], yum=["libxml2-devel", "libxslt"]
+        )
         vtk_cmake_args = [
             "-DModule_vtkIOXML=ON",
             "-DModule_vtkIOLegacy=ON",
@@ -425,8 +429,11 @@ if local_args.ogs != "clean":
             prefix="/usr/local/eigen",
             url=f"https://gitlab.com/libeigen/eigen/-/archive/{eigen_version}/eigen-{eigen_version}.tar.gz",
         )
+        hdf5_cofigure_opts = ["--enable-cxx"]
+        if toolchain.CC == "mpicc":
+            hdf5_cofigure_opts = ["--enable-parallel", "--enable-shared"]
         Stage0 += hdf5(
-            configure_opts=["--enable-cxx"],
+            configure_opts=hdf5_cofigure_opts,
             toolchain=toolchain,
             version=versions["minimum_version"]["hdf5"],
         )
@@ -464,17 +471,29 @@ if local_args.dev:
     )
 
 if local_args.mfront:
+    tfel_version = versions["minimum_version"]["tfel-rliv"]
     Stage0 += generic_cmake(
-        directory="tfel-TFEL-3.3.0",
+        cmake_opts=['-Denable-python-bindings=ON'],
+        directory=f"tfel-rliv-{tfel_version}",
         ldconfig=True,
-        url="https://github.com/thelfer/tfel/archive/TFEL-3.3.0.tar.gz",
+        url=f"https://github.com/thelfer/tfel/archive/refs/heads/rliv-{tfel_version}.zip",
         prefix="/usr/local/tfel",
+        runtime_environment={"PATH": "/usr/local/tfel/bin:$PATH"},
+        devel_environment={"PATH": "/usr/local/tfel/bin:$PATH"},
     )
-    Stage0 += environment(variables={"TFELHOME": "/usr/local/tfel"})
+    tfel_env = environment(
+        variables={
+            "TFELHOME": "/usr/local/tfel",
+            # TODO: Don't hard-code python version
+            "PYTHONPATH": "/usr/local/tfel/lib/python3.8/site-packages:$PYTHONPATH"
+        }
+    )
+    Stage0 += tfel_env
+    Stage1 += tfel_env
     cmake_args.append("-DOGS_USE_MFRONT=ON")
 
 if local_args.mkl:
-    Stage0 += mkl(eula=True)
+    Stage0 += mkl(eula=True, mklvars=False)
     cmake_args.append("-DOGS_USE_MKL=ON")
 
 if local_args.ccache:
@@ -495,23 +514,16 @@ if local_args.ogs != "off" and local_args.ogs != "clean":
     if repo == "local":
         print(f"chdir to {local_args.ogs}")
         os.chdir(local_args.ogs)
-        mount_args += f" --mount=type=bind,target=/scif/apps/ogs/src,rw"
 
-    ogs_app = scif(_arguments=mount_args, name="ogs", file=scif_file)
-    ogs_app += ogs(
+    Stage0 += ogs(
         repo=repo,
         branch=branch,
         commit=commit_hash,
         conan=(True if local_args.pm == "conan" else False),
         git_version=git_version,
         toolchain=toolchain,
-        prefix="/scif/apps/ogs",
         cmake_args=cmake_args,
         parallel=local_args.parallel,
         remove_build=True,
         remove_source=True,
     )
-    # Install scif in all stages
-    Stage0 += pip(packages=["scif"], pip="pip3")
-    Stage1 += pip(packages=["scif"], pip="pip3")
-    Stage0 += ogs_app
